[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Emacs-diffs] emacs-24 r117284: * net/tramp-adb.el (tramp-adb-handle-pro
From: |
Michael Albinus |
Subject: |
[Emacs-diffs] emacs-24 r117284: * net/tramp-adb.el (tramp-adb-handle-process-file): |
Date: |
Sun, 22 Jun 2014 09:20:50 +0000 |
User-agent: |
Bazaar (2.6b2) |
------------------------------------------------------------
revno: 117284
revision-id: address@hidden
parent: address@hidden
fixes bug: http://debbugs.gnu.org/17815
committer: Michael Albinus <address@hidden>
branch nick: emacs-24
timestamp: Sun 2014-06-22 11:20:38 +0200
message:
* net/tramp-adb.el (tramp-adb-handle-process-file):
* net/tramp-sh.el (tramp-sh-handle-process-file):
* net/tramp-smb.el (tramp-smb-handle-process-file): Do not raise
the output buffer when DISPLAY is non-nil.
modified:
lisp/ChangeLog changelog-20091113204419-o5vbwnq5f7feedwu-1432
lisp/net/tramp-adb.el trampadb.el-20121204164216-03wyr5miam215d7f-1
lisp/net/tramp-sh.el trampsh.el-20100913133439-a1faifh29eqoi4nh-1
lisp/net/tramp-smb.el
trampsmb.el-20091113204419-o5vbwnq5f7feedwu-2515
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog 2014-06-21 21:21:46 +0000
+++ b/lisp/ChangeLog 2014-06-22 09:20:38 +0000
@@ -1,3 +1,10 @@
+2014-06-22 Michael Albinus <address@hidden>
+
+ * net/tramp-adb.el (tramp-adb-handle-process-file):
+ * net/tramp-sh.el (tramp-sh-handle-process-file):
+ * net/tramp-smb.el (tramp-smb-handle-process-file): Do not raise
+ the output buffer when DISPLAY is non-nil. (Bug#17815)
+
2014-06-21 Glenn Morris <address@hidden>
* play/landmark.el (landmark-move-down, landmark-move-up):
=== modified file 'lisp/net/tramp-adb.el'
--- a/lisp/net/tramp-adb.el 2014-04-18 18:57:04 +0000
+++ b/lisp/net/tramp-adb.el 2014-06-22 09:20:38 +0000
@@ -801,11 +801,11 @@
v (format "(cd %s; %s)"
(tramp-shell-quote-argument localname) command)
"")
- ;; We should show the output anyway.
+ ;; We should add the output anyway.
(when outbuf
(with-current-buffer outbuf
(insert-buffer-substring (tramp-get-connection-buffer v)))
- (when display (display-buffer outbuf))))
+ (when (and display (get-buffer-window outbuf t)) (redisplay))))
;; When the user did interrupt, we should do it also. We use
;; return code -1 as marker.
(quit
=== modified file 'lisp/net/tramp-sh.el'
--- a/lisp/net/tramp-sh.el 2014-05-17 09:00:54 +0000
+++ b/lisp/net/tramp-sh.el 2014-06-22 09:20:38 +0000
@@ -2906,13 +2906,13 @@
command)
t t)
0 1))
- ;; We should show the output anyway.
+ ;; We should add the output anyway.
(when outbuf
(with-current-buffer outbuf
(insert
(with-current-buffer (tramp-get-connection-buffer v)
(buffer-string))))
- (when display (display-buffer outbuf))))
+ (when (and display (get-buffer-window outbuf t)) (redisplay))))
;; When the user did interrupt, we should do it also. We use
;; return code -1 as marker.
(quit
=== modified file 'lisp/net/tramp-smb.el'
--- a/lisp/net/tramp-smb.el 2014-02-19 19:24:32 +0000
+++ b/lisp/net/tramp-smb.el 2014-06-22 09:20:38 +0000
@@ -1224,8 +1224,8 @@
(error
(setq ret 1)))
- ;; We should show the output anyway.
- (when (and outbuf display) (display-buffer outbuf))
+ ;; We should redisplay the output.
+ (when (and display outbuf (get-buffer-window outbuf t)) (redisplay))
;; Cleanup. We remove all file cache values for the connection,
;; because the remote process could have changed them.
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- [Emacs-diffs] emacs-24 r117284: * net/tramp-adb.el (tramp-adb-handle-process-file):,
Michael Albinus <=